@@ -2,26 +2,6 @@
 
 use crate::co::*;
 
-const_ordinary! { FDEOR: u32;
-	/// [`FDE_OVERWRITE_RESPONSE`](https://learn.microsoft.com/en-us/windows/win32/api/shobjidl_core/ne-shobjidl_core-fde_overwrite_response)
-	/// enumeration (`u32`).
-	=>
-	=>
-	DEFAULT 0
-	ACCEPT 1
-	REFUSE 2
-}
-
-const_ordinary! { FDESVR: u32;
-	/// [`FDE_SHAREVIOLATION_RESPONSE`](https://learn.microsoft.com/en-us/windows/win32/api/shobjidl_core/ne-shobjidl_core-fde_shareviolation_response)
-	/// enumeration (`u32`).
-	=>
-	=>
-	DEFAULT 0
-	ACCEPT 1
-	REFUSE 2
-}
-
 const_ordinary! { FO: u32;
 	/// [`SHFILEOPSTRUCT`](crate::SHFILEOPSTRUCT) `wFunc` (`u32`).
 	=>
@@ -188,20 +168,6 @@ const_bitflag! { GPS: u32;
 	MASK_VALID 0x1fff
 }
 
-const_bitflag! { HOTKEYF: u16;
-	/// [`wm::GetHotkey`](crate::msg::wm::GetHotKey) and
-	/// [`wm::SetHotKey`](crate::msg::wm::SetHotKey) modifiers;
-	/// [`SHELLEXECUTEINFO`](crate::SHELLEXECUTEINFO) `dwHotKey` (`u16`).
-	=>
-	=>
-	/// None of the actual values (zero).
-	NoValue 0
-	ALT 0x04
-	CONTROL 0x02
-	EXT 0x08
-	SHIFT 0x01
-}
-
 const_bitflag! { KF: u32;
 	/// [`KNOWN_FOLDER_FLAG`](https://learn.microsoft.com/en-us/windows/win32/api/shlobj_core/ne-shlobj_core-known_folder_flag)
 	/// enumeration (`u32`).
@@ -273,6 +239,27 @@ const_bitflag! { NIS: u32;
 	SHAREDICON 0x0000_0002
 }
 
+const_ordinary! { SE_ERR: u32;
+	/// [`HWND::ShellExecute`](crate::prelude::shell_Hwnd::ShellExecute) return
+	/// value (`u32`).
+	=>
+	=>
+	FILE_NOT_FOUND 2
+	PATH_NOT_FOUND 3
+	BAD_FORMAT 11
+
+	ACCESSDENIED 5
+	OOM 8
+	DLLNOTFOUND 32
+
+	SHARE 26
+	ASSOCINCOMPLETE 27
+	DDETIMEOUT 28
+	DDEFAIL 29
+	DDEBUSY 30
+	NOASSOC 31
+}
+
 const_bitflag! { SFGAO: u32;
 	/// [`SFGAO`](https://learn.microsoft.com/en-us/windows/win32/shell/sfgao)
 	/// constants (`u32`).
